API library documentation
=========================

The API library documentation references the internals of `mdacli`. Only
advanced users with very specific development goals might need to use such
interfaces. A regular user wanting to use `mdacli` from the command-line does
not need to refer to these pages, refer to :ref:`usage` instead.

.. toctree::
   :maxdepth: 1

   api/cli
   api/libcli
   api/save
   api/colors
   api/logger
   api/utils
